createEmptyInstance method
Creates an empty instance of the same message type as this.
Implementation
AnalyzeEntitySentimentResponse createEmptyInstance() => create();
Creates an empty instance of the same message type as this.
AnalyzeEntitySentimentResponse createEmptyInstance() => create();