createEmptyInstance method
Creates an empty instance of the same message type as this.
Implementation
AnalyzeSyntaxResponse createEmptyInstance() => create();
Creates an empty instance of the same message type as this.
AnalyzeSyntaxResponse createEmptyInstance() => create();