createEmptyInstance method
Creates an empty instance of the same message type as this.
Implementation
AnnotateTextRequest_Features createEmptyInstance() => create();
Creates an empty instance of the same message type as this.
AnnotateTextRequest_Features createEmptyInstance() => create();