createEmptyInstance method
Creates an empty instance of the same message type as this.
Implementation
GcsDestination createEmptyInstance() => create();
Creates an empty instance of the same message type as this.
GcsDestination createEmptyInstance() => create();