createEmptyInstance method
Creates an empty instance of the same message type as this.
Implementation
InputConfig createEmptyInstance() => create();
Creates an empty instance of the same message type as this.
InputConfig createEmptyInstance() => create();