createEmptyInstance method
Creates an empty instance of the same message type as this.
Implementation
ListGlossariesRequest createEmptyInstance() => create();
Creates an empty instance of the same message type as this.
ListGlossariesRequest createEmptyInstance() => create();