createEmptyInstance method
Creates an empty instance of the same message type as this.
Implementation
LongRunningRecognizeResponse createEmptyInstance() => create();
Creates an empty instance of the same message type as this.
LongRunningRecognizeResponse createEmptyInstance() => create();