createEmptyInstance method
Creates an empty instance of the same message type as this.
Implementation
OutputConfig createEmptyInstance() => create();
Creates an empty instance of the same message type as this.
OutputConfig createEmptyInstance() => create();