createEmptyInstance method
Creates an empty instance of the same message type as this.
Implementation
BreakResponse createEmptyInstance() => create();
Creates an empty instance of the same message type as this.
BreakResponse createEmptyInstance() => create();