createEmptyInstance method
Creates an empty instance of the same message type as this.
Implementation
StemmResponseSimple createEmptyInstance() => create();
Creates an empty instance of the same message type as this.
StemmResponseSimple createEmptyInstance() => create();